 
#include "acp_base.h" 
 
#include "mth.h" 
#include "GEO.h"
#include "Gmt.h"
#include "mec.h"
 
 
 
#ifndef _FIRE_DEADCODE_U64_ /* Added by RUC */
void
GEO_xCreateFaceMapDescriptor ( ACP_tdxHandleOfFMD  *hFmd ) 
{
   GEO_M_CPAMalloc (
        *hFmd ,
        GEO_tdstFaceMapDescriptor *,
	    sizeof(GEO_tdstFaceMapDescriptor),
		E_uwGEONotEnoughtMemory );
}
 
void
GEO_xSetFaceMapDescriptorUV ( ACP_tdxHandleOfFMD  hFmd ,
							  ACP_tdst2DUVValues *p_stUVA,
							  ACP_tdst2DUVValues *p_stUVB,
							  ACP_tdst2DUVValues *p_stUVC) 
{
   hFmd-> stUVValues[0] = *p_stUVA;
   hFmd-> stUVValues[1] = *p_stUVB;
   hFmd-> stUVValues[2] = *p_stUVC;
}
#endif /* _FIRE_DEADCODE_U64_ */ /* Added by RUC */
 
 
#ifndef _FIRE_DEADCODE_U64_
void
GEO_xGetFaceMapDescriptorUV ( ACP_tdxHandleOfFMD  hFmd ,
							  ACP_tdst2DUVValues *p_stUVA,
							  ACP_tdst2DUVValues *p_stUVB,
							  ACP_tdst2DUVValues *p_stUVC) 
{
   *p_stUVA = hFmd-> stUVValues[0] ;
   *p_stUVB = hFmd-> stUVValues[1] ;
   *p_stUVC = hFmd-> stUVValues[2] ;
}
 
void
GEO_xSetFaceMapDescriptorMaterial ( ACP_tdxHandleOfFMD  hFmd ,
							        ACP_tdxHandleOfMaterial  hMaterial)
{
   GMT_fn_vSetVisualMaterial(hFmd-> hMaterial, hMaterial);
}
#endif /* _FIRE_DEADCODE_U64_ */
 
 
#ifndef _FIRE_DEADCODE_U64_ /* Added by RUC */
void
GEO_xGetFaceMapDescriptorMaterial ( ACP_tdxHandleOfFMD  hFmd ,
							        ACP_tdxHandleOfMaterial  *p_hMaterial)
{
	*p_hMaterial=GMT_fn_hGetVisualMaterial( hFmd-> hMaterial );
}
 
/*
////////////////////////////////////////////////////////////////////////////////
// Description : GEO_xSetFaceMapDescriptorGameMaterial
//               Set the game material of a FMD
////////////////////////////////////////////////////////////////////////////////
// Input : hFmd : handle to the FMD
//			hMaterial : handle to the game material
// Output : 
////////////////////////////////////////////////////////////////////////////////
// Creation date : Feb 1997               Author : A.R.
////////////////////////////////////////////////////////////////////////////////
*/
void
GEO_xSetFaceMapDescriptorGameMaterial ( ACP_tdxHandleOfFMD  hFmd ,
							        GMT_tdxHandleToGameMaterial  hMaterial)
{
   hFmd-> hMaterial = hMaterial;
}
#endif /* _FIRE_DEADCODE_U64_ */ /* Added by RUC */
 
 
/*
////////////////////////////////////////////////////////////////////////////////
// Description : GEO_xSetFaceMapDescriptorGameMaterial
//               Set the game material of a FMD
////////////////////////////////////////////////////////////////////////////////
// Input : hFmd : handle to the FMD
//			hMaterial : handle to the game material
// Output : 
////////////////////////////////////////////////////////////////////////////////
// Creation date : Feb 1997               Author : A.R.
////////////////////////////////////////////////////////////////////////////////
*/
void
GEO_xGetFaceMapDescriptorGameMaterial ( ACP_tdxHandleOfFMD  hFmd ,
							        GMT_tdxHandleToGameMaterial  *p_hMaterial)
{
	*p_hMaterial = hFmd-> hMaterial ;
}
 
